@@ -2,7 +2,8 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.utils import timezone
 from django.utils.timezone import timezone, timedelta, datetime
-
+from django.contrib.auth.models import User
+#from userprofile.models import AbstractSubscriptionProfile
 from address.models import AddressField, Address
 from phonenumber_field.modelfields import PhoneNumberField
 import uuid
@@ -201,4 +202,12 @@ class Person(models.Model):
 
     def __str__(self):
         return str(self.full_name)
-
+#
+# class Account(AbstractSubscriptionProfile, models.Model):
+#      """
+#      Felhasználói fiók
+#      """
+#      class Meta:
+#          db_table = 'accounts'
+#          verbose_name = _("felhasználói fiók")
+#          verbose_name_plural = _("felhasználói fiókok")
\ No newline at end of file
