@@ -40,6 +40,7 @@ from labor.models import Salary
 from labor.models import BankAccount
 from labor.models import Salary
 from labor.models import SalaryBlockingItem
+from labor.models import Dependence
 
 import calendar
 from random import choice, randint
@@ -120,6 +121,7 @@ class Command(BaseCommand):
         SalaryBlockingItem.objects.all().delete()
 
         Salary.objects.all().delete()
+        Dependence.objects.all().delete()
         Employment.objects.all().delete()
 
         Organization.objects.all().delete()
@@ -820,12 +822,14 @@ class Command(BaseCommand):
                 employer=str(employer),
                 type=str(aq)
             )
-            Employment.objects.create(
+            employment = Employment.objects.create(
                 employee=employee,
                 employer=employer,
                 type=aq,
             )
 
+            self.generate_dependencies(amount=10, provider=employment)
+
 
     def pay_salaries(self, minimum: int = 100000, maximum: int = 10000000, begin: datetime = datetime(year=2018, month=1, day=1), end: datetime = datetime.now()):
         for employment in Employment.objects.all():
@@ -854,14 +858,31 @@ class Command(BaseCommand):
                     self.log_timesheets(salary=s,year=year, month=month)
                     self.generate_blocked_salaries(salary=s)
 
-    def generate_blocked_salaries(self, salary: Salary):
-        for b in range(0, randint(0, 10)):
+    def generate_blocked_salaries(self, salary: Salary, amount: int = 10, minimum: int = 0, maximum: int = 100000):
+        for b in range(0, randint(0, amount)):
             SalaryBlockingItem.objects.create(
                 salary=salary,
-                value=randint(0, 100000),
+                value=randint(minimum, maximum),
                 account=choice(BankAccount.objects.all()),
             )
 
+    def generate_dependencies(self, provider: Employment, amount: int = 10):
+        for d in range(0, randint(0, amount)):
+            year = randint(1900, 2020)
+            month = randint(1, 12)
+            day = randint(*calendar.monthrange(year, month)) % 27 + 1
+            q = choice(DependentQuality.objects.all())
+            r = choice(DependentRight.objects.all())
+            dependent = choice(Person.objects.all())
+            Dependence.objects.create(
+                dependent=dependent,
+                provider=provider,
+                quality=q,
+                right=r,
+                begin=datetime(year=year, month=month, day=day),
+                end=datetime(year=year+randint(1, 10), month=month, day=day),
+            )
+
     def _highlight(self, message: str, **kwargs):
         self.stdout.write(message.format(
             **kwargs
